.. _trojanzoo.utils:

utils
======

.. currentmodule:: trojanzoo.utils

.. toctree::
   :maxdepth: 2

   data
   fim
   logger
   model
   module
   tensor
   train

.. autoclass:: trojanzoo.utils.lock.Lock
   :members:

.. autofunction:: trojanzoo.utils.memory.empty_cache
.. autofunction:: trojanzoo.utils.memory.output_memory
